Returns a geometry that represents all points whose distance from this Geometry is less than or equal to distance.
Arguments
- x
dbSpatialobject- dist
numeric distance
- ...
additional arguments
Value
dbSpatial object with buffered geometry
See also
Other geometry_ops:
st_centroid(),
st_simplify()