Returns the geometry type for each row in a dbSpatial object using DuckDB's
spatial function ST_GeometryType().
Arguments
- dbSpatial
A dbSpatial object.
- geomName
Geometry column name. Default:
"geom".- collect
Logical (default =
FALSE). IfTRUE, collect results into a character vector.- n
Optional integer. If provided alongside
collect = TRUE, limits the query to the firstnrows before collecting.- ...
Additional arguments (ignored).